searchNodes=[{"doc":"This module defines the behaviour for implementing clustering strategies.","ref":"Cluster.Strategy.html","title":"Cluster.Strategy","type":"behaviour"},{"doc":"","ref":"Cluster.Strategy.html#c:child_spec/1","title":"Cluster.Strategy.child_spec/1","type":"callback"},{"doc":"Given a list of node names, attempts to connect to all of them. Returns :ok if all nodes connected, or {:error, [{node, reason}, ..]} if we failed to connect to some nodes. All failures are logged.","ref":"Cluster.Strategy.html#connect_nodes/4","title":"Cluster.Strategy.connect_nodes/4","type":"function"},{"doc":"","ref":"Cluster.Strategy.html#difference/2","title":"Cluster.Strategy.difference/2","type":"function"},{"doc":"Given a list of node names, attempts to disconnect from all of them. Returns :ok if all nodes disconnected, or {:error, [{node, reason}, ..]} if we failed to disconnect from some nodes. All failures are logged.","ref":"Cluster.Strategy.html#disconnect_nodes/4","title":"Cluster.Strategy.disconnect_nodes/4","type":"function"},{"doc":"","ref":"Cluster.Strategy.html#intersection/2","title":"Cluster.Strategy.intersection/2","type":"function"},{"doc":"","ref":"Cluster.Strategy.html#c:start_link/1","title":"Cluster.Strategy.start_link/1","type":"callback"},{"doc":"","ref":"Cluster.Strategy.html#t:bad_nodes/0","title":"Cluster.Strategy.bad_nodes/0","type":"type"},{"doc":"","ref":"Cluster.Strategy.html#t:mfa_tuple/0","title":"Cluster.Strategy.mfa_tuple/0","type":"type"},{"doc":"","ref":"Cluster.Strategy.html#t:strategy_args/0","title":"Cluster.Strategy.strategy_args/0","type":"type"},{"doc":"","ref":"Cluster.Strategy.html#t:topology/0","title":"Cluster.Strategy.topology/0","type":"type"},{"doc":"Assumes you have nodes that respond to the specified DNS query (A record), and which follow the node name pattern of &lt;name&gt;@&lt;ip-address&gt; . If your setup matches those assumptions, this strategy will periodically poll DNS and connect all nodes it finds. Options poll_interval - How often to poll in milliseconds (optional; default: 5_000) query - DNS query to use (required; e.g. &quot;my-app.example.com&quot;) node_basename - The short name of the nodes you wish to connect to (required; e.g. &quot;my-app&quot;) Usage config :libcluster , topologies : [ dns_poll_example : [ strategy : Elixir.Cluster.Strategy.DNSPoll , config : [ polling_interval : 5_000 , query : &quot;my-app.example.com&quot; , node_basename : &quot;my-app&quot; ] ] ]","ref":"Cluster.Strategy.DNSPoll.html","title":"Cluster.Strategy.DNSPoll","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.DNSPoll.html#child_spec/1","title":"Cluster.Strategy.DNSPoll.child_spec/1","type":"function"},{"doc":"","ref":"Cluster.Strategy.DNSPoll.html#lookup_all_ips/1","title":"Cluster.Strategy.DNSPoll.lookup_all_ips/1","type":"function"},{"doc":"","ref":"Cluster.Strategy.DNSPoll.html#start_link/1","title":"Cluster.Strategy.DNSPoll.start_link/1","type":"function"},{"doc":"This clustering strategy relies on Erlang's built-in distribution protocol. You can have libcluster automatically connect nodes on startup for you by configuring the strategy like below: config :libcluster , topologies : [ epmd_example : [ strategy : Elixir.Cluster.Strategy.Epmd , config : [ hosts : [ :&quot;a@127.0.0.1&quot; , :&quot;b@127.0.0.1&quot; ] ] ] ]","ref":"Cluster.Strategy.Epmd.html","title":"Cluster.Strategy.Epmd","type":"module"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.Epmd.html#start_link/1","title":"Cluster.Strategy.Epmd.start_link/1","type":"function"},{"doc":"This clustering strategy relies on Erlang's built-in distribution protocol by using a .hosts.erlang file (as used by the :net_adm module). Please see the net_adm docs for more details. In short, the following is the gist of how it works: File .hosts.erlang consists of a number of host names written as Erlang terms. It is looked for in the current work directory, the user's home directory, and $OTP_ROOT (the root directory of Erlang/OTP), in that order. This looks a bit like the following in practice: &#39;super.eua.ericsson.se&#39; . &#39;renat.eua.ericsson.se&#39; . &#39;grouse.eua.ericsson.se&#39; . &#39;gauffin1.eua.ericsson.se&#39; . You can have libcluster automatically connect nodes on startup for you by configuring the strategy like below: config :libcluster , topologies : [ erlang_hosts_example : [ strategy : Elixir.Cluster.Strategy.ErlangHosts , config : [ timeout : 30_000 ] ] ] An optional timeout can be specified in the config. This is the timeout that will be used in the GenServer to connect the nodes. This defaults to :infinity meaning that the connection process will only happen when the worker is started. Any integer timeout will result in the connection process being triggered. In the example above, it has been configured for 30 seconds.","ref":"Cluster.Strategy.ErlangHosts.html","title":"Cluster.Strategy.ErlangHosts","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.ErlangHosts.html#child_spec/1","title":"Cluster.Strategy.ErlangHosts.child_spec/1","type":"function"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.ErlangHosts.html#start_link/1","title":"Cluster.Strategy.ErlangHosts.start_link/1","type":"function"},{"doc":"This clustering strategy uses multicast UDP to gossip node names to other nodes on the network. These packets are listened for on each node as well, and a connection will be established between the two nodes if they are reachable on the network, and share the same magic cookie. In this way, a cluster of nodes may be formed dynamically. The gossip protocol is extremely simple, with a prelude followed by the node name which sent the packet. The node name is parsed from the packet, and a connection attempt is made. It will fail if the two nodes do not share a cookie. By default, the gossip occurs on port 45892, using the multicast address 233.252.1.32 The gossip protocol is not encrypted by default, but can be by providing a secret in the configuration of the strategy (as shown below). This can also be used to run multiple clusters with the same multicast configuration, as nodes not sharing the same encryption key will not be connected. You may configure the multicast interface, multicast address, the interface address to bind to, the port, the TTL of the packets and the optional secret using the following settings: config :libcluster , topologies : [ gossip_example : [ strategy : Elixir.Cluster.Strategy.Gossip , config : [ port : 45892 , if_addr : &quot;0.0.0.0&quot; , multicast_if : &quot;192.168.1.1&quot; , multicast_addr : &quot;233.252.1.32&quot; , multicast_ttl : 1 , secret : &quot;somepassword&quot; ] ] ] A TTL of 1 will limit packets to the local network, and is the default TTL. Optionally, broadcast_only: true option can be set which disables multicast and only uses broadcasting. This limits connectivity to local network but works on in scenarios where multicast is not enabled. Use multicast_addr as the broadcast address. Example for broadcast only: config :libcluster , topologies : [ gossip_example : [ strategy : Elixir.Cluster.Strategy.Gossip , config : [ port : 45892 , if_addr : &quot;0.0.0.0&quot; , multicast_addr : &quot;255.255.255.255&quot; , broadcast_only : true ] ] ] Debug logging is deactivated by default for this clustering strategy, but it can be easily activated by configuring the application: use Mix.Config config :libcluster , debug : true All the checks are done at runtime, so you can flip the debug level without being forced to shutdown your node.","ref":"Cluster.Strategy.Gossip.html","title":"Cluster.Strategy.Gossip","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.Gossip.html#child_spec/1","title":"Cluster.Strategy.Gossip.child_spec/1","type":"function"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.Gossip.html#start_link/1","title":"Cluster.Strategy.Gossip.start_link/1","type":"function"},{"doc":"This clustering strategy works by loading all endpoints in the current Kubernetes namespace with the configured label. It will fetch the addresses of all endpoints with that label and attempt to connect. It will continually monitor and update its connections every 5s. Alternatively the IP can be looked up from the pods directly by setting kubernetes_ip_lookup_mode to :pods . In order for your endpoints to be found they should be returned when you run: kubectl get endpoints - l app = myapp In order for your pods to be found they should be returned when you run: kubectl get pods - l app = myapp It assumes that all nodes share a base name, are using longnames, and are unique based on their FQDN, rather than the base hostname. In other words, in the following longname, &lt;basename&gt;@&lt;domain&gt; , basename would be the value configured in kubernetes_node_basename . domain would be the value configured in mode and can be either of type :ip (the pod's ip, can be obtained by setting an env variable to status.podIP), :hostname or :dns , which is the pod's internal A Record. This A Record has the format &lt;ip-with-dashes&gt;.&lt;namespace&gt;.pod.cluster.local , e.g. 1-2-3-4.default.pod.cluster.local . Getting :dns to work requires setting the POD_A_RECORD environment variable before the application starts. If you use Distillery you can set it in your pre_configure hook: # deployment.yaml command : [ &quot;sh&quot; , &quot;-c&quot; ] args : [ &quot;POD_A_RECORD&quot; ] args : [ &quot;export POD_A_RECORD=$(echo $POD_IP | sed &#39;s/ \\. /-/g&#39;) &amp;&amp; /app/bin/app foreground&quot; ] # vm.args - name app @ &lt; % = &quot;${POD_A_RECORD}.${NAMESPACE}.pod.cluster.local&quot; % &gt; If you use mix releases instead, you can configure the required options in rel/env.sh.eex . Doing so will append a -name option to the start command directly and requires no further changes to the vm.args : # rel/env.sh.eex export POD_A_RECORD = $ ( echo $ POD_IP | sed &#39;s/ \\. /-/g&#39; ) export RELEASE_DISTRIBUTION = name export RELEASE_NODE = &lt; % = @release . name % &gt; @ $ { POD_A_RECORD } . $ { NAMESPACE } . pod . cluster . local To set the NAMESPACE and POD_IP environment variables you can configure your pod as follows: # deployment.yaml env : - name : NAMESPACE valueFrom : fieldRef : fieldPath : metadata . namespace - name : POD_IP valueFrom : fieldRef : fieldPath : status . podIP The benefit of using :dns over :ip is that you can establish a remote shell (as well as run observer) by using kubectl port-forward in combination with some entries in /etc/hosts . Using :hostname is useful when deploying your app to K8S as a stateful set. In this case you can set your erlang name as the fully qualified domain name of the pod which would be something similar to my-app-0.my-service-name.my-namespace.svc.cluster.local . e.g. # vm.args - name app @ &lt; % = ` ( hostname - f ) ` % &gt; In this case you must also set kubernetes_service_name to the name of the K8S service that is being queried. mode defaults to :ip . An example configuration is below: config :libcluster , topologies : [ k8s_example : [ strategy : \#{__MODULE__}, config : [ mode : :ip , kubernetes_node_basename : &quot;myapp&quot; , kubernetes_selector : &quot;app=myapp&quot; , kubernetes_namespace : &quot;my_namespace&quot; , polling_interval : 10_000 ] ] ]","ref":"Cluster.Strategy.Kubernetes.html","title":"Cluster.Strategy.Kubernetes","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.Kubernetes.html#child_spec/1","title":"Cluster.Strategy.Kubernetes.child_spec/1","type":"function"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.Kubernetes.html#start_link/1","title":"Cluster.Strategy.Kubernetes.start_link/1","type":"function"},{"doc":"This clustering strategy works by loading all your Erlang nodes (within Pods) in the current Kubernetes namespace . It will fetch the addresses of all pods under a shared headless service and attempt to connect. It will continually monitor and update its connections every 5s. It assumes that all Erlang nodes were launched under a base name, are using longnames, and are unique based on their FQDN, rather than the base hostname. In other words, in the following longname, &lt;basename&gt;@&lt;ip&gt; , basename would be the value configured through application_name . An example configuration is below: config :libcluster , topologies : [ k8s_example : [ strategy : Elixir.Cluster.Strategy.Kubernetes.DNS , config : [ service : &quot;myapp-headless&quot; , application_name : &quot;myapp&quot; , polling_interval : 10_000 ] ] ]","ref":"Cluster.Strategy.Kubernetes.DNS.html","title":"Cluster.Strategy.Kubernetes.DNS","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.Kubernetes.DNS.html#child_spec/1","title":"Cluster.Strategy.Kubernetes.DNS.child_spec/1","type":"function"},{"doc":"This clustering strategy works by issuing a SRV query for the kubernetes headless service under which the stateful set containing your nodes is running. For more information, see the kubernetes stateful-application documentation It will fetch the FQDN of all pods under the headless service and attempt to connect. It will continually monitor and update its connections according to the polling_interval (default 5s) The application_name is configurable (you may have launched erlang with a different configured name), but will in most cases be the name of your application An example configuration is below: config :libcluster , topologies : [ k8s_example : [ strategy : Elixir.Cluster.Strategy.Kubernetes.DNSSRV , config : [ service : &quot;elixir-plug-poc&quot; , application_name : &quot;elixir_plug_poc&quot; , namespace : &quot;default&quot; , polling_interval : 10_000 ] ] ] An example of how this strategy extracts topology information from DNS follows: bash - 5.0 # hostname -f elixir - plug - poc - 1 . elixir - plug - poc . default . svc . cluster . local bash - 5.0 # dig SRV elixir-plug-poc.default.svc.cluster.local ; &lt;&lt; &gt;&gt; DiG 9.14 . 3 &lt;&lt; &gt;&gt; SRV elixir - plug - poc . default . svc . cluster . local ; ; global options : + cmd ; ; Got answer : ; ; WARNING : . local is reserved for Multicast DNS ; ; You are currently testing what happens when an mDNS query is leaked to DNS ; ; -&gt; &gt; HEADER &lt;&lt; - opcode : QUERY , status : NOERROR , id : 7169 ; ; flags : qr aa rd ra ; QUERY : 1 , ANSWER : 2 , AUTHORITY : 0 , ADDITIONAL : 2 ; ; QUESTION SECTION : ; elixir - plug - poc . default . svc . cluster . local . IN SRV ; ; ANSWER SECTION : elixir - plug - poc . default . svc . cluster . local . 30 IN SRV 10 50 0 elixir - plug - poc - 0 . elixir - plug - poc . default . svc . cluster . local . elixir - plug - poc . default . svc . cluster . local . 30 IN SRV 10 50 0 elixir - plug - poc - 1 . elixir - plug - poc . default . svc . cluster . local . ; ; ADDITIONAL SECTION : elixir - plug - poc - 0 . elixir - plug - poc . default . svc . cluster . local . 30 IN A 10.1 . 0.95 elixir - plug - poc - 1 . elixir - plug - poc . default . svc . cluster . local . 30 IN A 10.1 . 0.96 ; ; Query time : 0 msec ; ; SERVER : 10.96 . 0.10 #53(10.96.0.10) ; ; WHEN : Wed Jul 03 11 : 55 : 27 UTC 2019 ; ; MSG SIZE rcvd : 167 And here is an example of a corresponding kubernetes statefulset/service definition: apiVersion: v1 kind: Service metadata: name: elixir-plug-poc labels: app: elixir-plug-poc spec: ports: - port: 4000 name: web clusterIP: None selector: app: elixir-plug-poc --- apiVersion: apps/v1 kind: StatefulSet metadata: name: elixir-plug-poc spec: serviceName: &quot;elixir-plug-poc&quot; replicas: 2 selector: matchLabels: app: elixir-plug-poc template: metadata: labels: app: elixir-plug-poc spec: containers: - name: elixir-plug-poc image: binarytemple/elixir_plug_poc args: - foreground env: - name: ERLANG_COOKIE value: &quot;cookie&quot; imagePullPolicy: Always ports: - containerPort: 4000 name: http protocol: TCP","ref":"Cluster.Strategy.Kubernetes.DNSSRV.html","title":"Cluster.Strategy.Kubernetes.DNSSRV","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.Kubernetes.DNSSRV.html#child_spec/1","title":"Cluster.Strategy.Kubernetes.DNSSRV.child_spec/1","type":"function"},{"doc":"This clustering strategy relies on Erlang's built-in distribution protocol. Unlike Cluster.Strategy.Empd, this strategy assumes that all nodes are on the local host and can be discovered by epmd. It should be configured as follows: config :libcluster , topologies : [ local_epmd_example : [ strategy : Elixir.Cluster.Strategy.LocalEpmd ] ]","ref":"Cluster.Strategy.LocalEpmd.html","title":"Cluster.Strategy.LocalEpmd","type":"module"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.LocalEpmd.html#start_link/1","title":"Cluster.Strategy.LocalEpmd.start_link/1","type":"function"},{"doc":"This clustering strategy is specific to the Rancher container platform. It works by querying the platform's metadata API for containers belonging to the same service as the node and attempts to connect them. (see: http://rancher.com/docs/rancher/latest/en/rancher-services/metadata-service/ ) It assumes that all nodes share a base name and are using longnames of the form &lt;basename@&lt;ip&gt; where the &lt;ip&gt; is unique for each node. A way to assign a name to a node on boot in an app running as a Distillery release is: Create a wrapper script which will interpolate the current ip of the container. #!/bin/sh export CONTAINER_IP=&quot;$(hostname -I | cut -f1 -d' ')&quot; export REPLACE_OS_VARS=true /app/bin/app &quot;$@&quot; # vm.args - name app @ $ { CONTAINER_IP } An example configuration is below: config :libcluster , topologies : [ rancher_example : [ strategy : Elixir.Cluster.Strategy.Rancher , config : [ node_basename : &quot;myapp&quot; , polling_interval : 10_000 ] ] ]","ref":"Cluster.Strategy.Rancher.html","title":"Cluster.Strategy.Rancher","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Strategy.Rancher.html#child_spec/1","title":"Cluster.Strategy.Rancher.child_spec/1","type":"function"},{"doc":"Callback implementation for Cluster.Strategy.start_link/1 .","ref":"Cluster.Strategy.Rancher.html#start_link/1","title":"Cluster.Strategy.Rancher.start_link/1","type":"function"},{"doc":"This module handles supervising the configured topologies, and is designed to support being started within your own supervision tree, as shown below: defmodule MyApp.App do use Application def start ( _type , _args ) do topologies = [ example : [ strategy : Cluster.Strategy.Epmd , config : [ hosts : [ :&quot;a@127.0.0.1&quot; , :&quot;b@127.0.0.1&quot; ] ] , ] ] children = [ { Cluster.Supervisor , [ topologies , [ name : MyApp.ClusterSupervisor ] ] } , .. other children .. ] Supervisor . start_link ( children , strategy : :one_for_one , name : MyApp.Supervisor ) end end The topologies configuration structure shown above can be built manually, like shown, so that you can load config at runtime in a way that best suits your application; or if you don't need to do any special config handling, you can use the Mix config file, and just use Application.get_env(:libcluster, :topologies) . That config would look like so: config :libcluster , topologies : [ example : [ ... ] ] Use the method most convenient for you.","ref":"Cluster.Supervisor.html","title":"Cluster.Supervisor","type":"module"},{"doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Cluster.Supervisor.html#child_spec/1","title":"Cluster.Supervisor.child_spec/1","type":"function"},{"doc":"Start a new instance of this supervisor. This is the callback indicated in the child specification returned by child_spec/1 . It expects a list of the form [config, supervisor_opts] , or [config] . The former allows you to provide options for the supervisor like with Supervisor.start_link/3 .","ref":"Cluster.Supervisor.html#start_link/1","title":"Cluster.Supervisor.start_link/1","type":"function"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Use new cypher names 3.3.0 Changed Default multicast address is now 233.252.1.32, was 230.1.1.251, commit 2.3.0 Added Clustering strategy for the Rancher container platform (see: https://github.com/rancher/rancher ) LocalEpmd strategy that uses epmd to discover nodes on the local host Gossip strategy multicast interface is used for adding multicast membership","ref":"changelog.html#unreleased","title":"Changelog - Unreleased","type":"extras"},{"doc":"Added Configurable connect and disconnect options for implementing strategies on top of custom topologies The ability to start libcluster for more than a single topology Added polling_interval option to Kubernetes strategy Added ability to specify a list of hosts for the Epmd strategy to connect to on start Removed Cluster.Events module, as it was redundant and unused Changed Configuration format has changed significantly, please review the docs","ref":"changelog.html#2-0-0","title":"Changelog - 2.0.0","type":"extras"},{"doc":"libcluster This library provides a mechanism for automatically forming clusters of Erlang nodes, with either static or dynamic node membership. It provides a pluggable &quot;strategy&quot; system, with a variety of strategies provided out of the box. You can find supporting documentation here .","ref":"readme.html","title":"libcluster","type":"extras"},{"doc":"Automatic cluster formation/healing Choice of multiple clustering strategies out of the box: Standard Distributed Erlang facilities (e.g. epmd , .hosts.erlang ), which supports IP-based or DNS-based names Multicast UDP gossip, using a configurable port/multicast address, Kubernetes via its metadata API using via a configurable label selector and node basename; or alternatively, using DNS. Rancher, via its metadata API Easy to provide your own custom clustering strategies for your specific environment. Easy to use provide your own distribution plumbing (i.e. something other than Distributed Erlang), by implementing a small set of callbacks. This allows libcluster to support projects like Partisan .","ref":"readme.html#features","title":"libcluster - Features","type":"extras"},{"doc":"defp deps do [ { :libcluster , &quot;~&gt; MAJ.MIN&quot; } ] end You can determine the latest version by running mix hex.info libcluster in your shell, or by going to the libcluster page on Hex.pm .","ref":"readme.html#installation","title":"libcluster - Installation","type":"extras"},{"doc":"It is easy to get started using libcluster , simply decide which strategy you want to use to form a cluster, define a topology, and then start the Cluster.Supervisor module in the supervision tree of an application in your Elixir system, as demonstrated below: defmodule MyApp.App do use Application def start ( _type , _args ) do topologies = [ example : [ strategy : Cluster.Strategy.Epmd , config : [ hosts : [ :&quot;a@127.0.0.1&quot; , :&quot;b@127.0.0.1&quot; ] ] , ] ] children = [ { Cluster.Supervisor , [ topologies , [ name : MyApp.ClusterSupervisor ] ] } , # ..other children.. ] Supervisor . start_link ( children , strategy : :one_for_one , name : MyApp.Supervisor ) end end The following section describes topology configuration in more detail.","ref":"readme.html#usage","title":"libcluster - Usage","type":"extras"},{"doc":"You can configure libcluster either in your Mix config file ( config.exs ) as shown below, or construct the keyword list structure manually, as shown in the previous section. Either way, you need to pass the configuration to the Cluster.Supervisor module in it's start arguments. If you prefer to use Mix config files, then simply use Application.get_env(:libcluster, :topologies) to get the config that Cluster.Supervisor expects. config :libcluster , topologies : [ example : [ # The selected clustering strategy. Required. strategy : Cluster.Strategy.Epmd , # Configuration for the provided strategy. Optional. config : [ hosts : [ :&quot;a@127.0.0.1&quot; , :&quot;b@127.0.0.1&quot; ] ] , # The function to use for connecting nodes. The node # name will be appended to the argument list. Optional connect : { :net_kernel , :connect_node , [ ] } , # The function to use for disconnecting nodes. The node # name will be appended to the argument list. Optional disconnect : { :erlang , :disconnect_node , [ ] } , # The function to use for listing nodes. # This function must return a list of node names. Optional list_nodes : { :erlang , :nodes , [ :connected ] } , ] ]","ref":"readme.html#example-configuration","title":"libcluster - Example Configuration","type":"extras"},{"doc":"For instructions on configuring each strategy included with libcluster , please visit the docs on HexDocs , and look at the module doc for the strategy you want to use. The authoritative documentation for each strategy is kept up to date with the module implementing it.","ref":"readme.html#strategy-configuration","title":"libcluster - Strategy Configuration","type":"extras"},{"doc":"You have a handful of choices with regards to cluster management out of the box: Cluster.Strategy.Epmd , which relies on epmd to connect to a configured set of hosts. Cluster.Strategy.LocalEpmd , which relies on epmd to connect to discovered nodes on the local host. Cluster.Strategy.ErlangHosts , which uses the .hosts.erlang file to determine which hosts to connect to. Cluster.Strategy.Gossip , which uses multicast UDP to form a cluster between nodes gossiping a heartbeat. Cluster.Strategy.Kubernetes , which uses the Kubernetes Metadata API to query nodes based on a label selector and basename. Cluster.Strategy.Kubernetes.DNS , which uses DNS to join nodes under a shared headless service in a given namespace. Cluster.Strategy.Rancher , which like the Kubernetes strategy, uses a metadata API to query nodes to cluster with. You can also define your own strategy implementation, by implementing the Cluster.Strategy behavior. This behavior expects you to implement a start_link/1 callback, optionally overriding child_spec/1 if needed. You don't necessarily have to start a process as part of your strategy, but since it's very likely you will need to maintain some state, designing your strategy as an OTP process (e.g. GenServer ) is the ideal method, however any valid OTP process will work. See the Cluster.Strategy module for details on the callbacks you need to implement and the arguments they receive. If you do not wish to use the default Erlang distribution protocol, you may provide an alternative means of connecting/ disconnecting nodes via the connect and disconnect configuration options, if not using Erlang distribution you must provide a list_nodes implementation as well. They take a {module, fun, args} tuple, and append the node name being targeted to the args list. How to implement distribution in this way is left as an exercise for the reader, but I recommend taking a look at the Firenest project currently under development. By default, libcluster uses Distributed Erlang. Third-Party Strategies The following list of third-party strategy implementations is not comprehensive, but are known to exist. libcluster_ec2 - EC2 clustering strategy based on tags libcluster_consul - Consul clustering strategy","ref":"readme.html#clustering","title":"libcluster - Clustering","type":"extras"},{"doc":"Copyright (c) 2016 Paul Schoenfelder This library is MIT licensed. See the LICENSE.md for details.","ref":"readme.html#copyright-and-license","title":"libcluster - Copyright and License","type":"extras"}]